Stan Math Library: stan/math/prim/mat/prob/multi_normal_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multi_normal_log.hpp File Reference
`#include <stan/math/prim/mat/err/check_ldlt_factor.hpp>`
`#include <stan/math/prim/mat/err/check_symmetric.hpp>`
`#include <stan/math/prim/mat/fun/trace_inv_quad_form_ldlt.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant_ldlt.hpp>`
`#include <stan/math/prim/mat/meta/VectorViewMvt.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/return_type.hpp>`
`#include <stan/math/prim/scal/meta/max_size_mvt.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <boost/random/normal_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_y , typename T_loc , typename T_covar >
return_type< T_y, T_loc, T_covar >::type | stan::math::multi_normal_log (const T_y &y, const T_loc &mu, const T_covar &Sigma)
template<typename T_y , typename T_loc , typename T_covar >
return_type< T_y, T_loc, T_covar >::type | stan::math::multi_normal_log (const T_y &y, const T_loc &mu, const T_covar &Sigma)

[ Stan Home Page ] © 2011–2016, Stan Development Team.